@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2001-2026 Zabbix SIA
+** Copyright (C) 2001-2025 Zabbix SIA
 **
 ** This program is free software: you can redistribute it and/or modify it under the terms of
 ** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
@@ -41,7 +41,7 @@ type Session struct {
 }
 
 type PluginOptions struct {
-	System plugin.SystemOptions `conf:"optional"` //nolint:staticcheck
+	plugin.SystemOptions `conf:"optional,name=System"`
 	// Timeout is the amount of time to wait for a server to respond when
 	// first connecting and on follow up operations in the session.
 	Timeout int `conf:"optional,range=1:30"`
@@ -59,7 +59,7 @@ type PluginOptions struct {
 // Configure implements the Configurator interface.
 // Initializes configuration structures.
 func (p *Plugin) Configure(global *plugin.GlobalOptions, options any) {
-	if err := conf.UnmarshalStrict(options, &p.options); err != nil {
+	if err := conf.Unmarshal(options, &p.options); err != nil {
 		p.Errf("cannot unmarshal configuration options: %s", err)
 	}
 
@@ -73,7 +73,7 @@ func (p *Plugin) Configure(global *plugin.GlobalOptions, options any) {
 func (*Plugin) Validate(options any) error {
 	var opts PluginOptions
 
-	err := conf.UnmarshalStrict(options, &opts)
+	err := conf.Unmarshal(options, &opts)
 	if err != nil {
 		return err
 	}
